The function extract_from_ll_wcsl() extracts specific elements from
a list of lists returned by the get_wcs_limit() function.
extract_from_ll_wcsl(ll, element)A list of the same length as ll_wcsl is returned. The
individual elements of the list are matrices of the values specified by
element that have been extracted from x.
A list of lists returned by the get_wcs_limit()
function. The list must have three elements named "cics",
"dics" and "dids". Each of these elements have a sub-list
of the same length as the number of intercepts. Each of these sub-lists
has a sub-sub-list of the same length as the number of release limits
(rl).
A character string specifying the element to be extracted,
i.e. either one of "delta.lim", "delta.lim.orig",
"wcs.lim" or "wcs.lim.orig".
Information in a bulk list of lists that has been obtained by
aid of the function get_wcs_limit() for a set of release
limit values (rl) and intercepts.
get_wcs_limit().