The function get_intvl_limit() calculates the upper or lower
confidence or prediction interval limit(s) at a given value of \(x\).
get_intvl_limit(
x_new,
model,
alpha = 0.05,
ivl = "confidence",
ivl_type = "one.sided",
ivl_side = "lower"
)A numeric value or, if the model contained a categorical variable, a numeric vector of the predicted upper or lower confidence or prediction interval limit(s) at a given value of \(x\).
A numeric value of \(x\) at which the upper or lower confidence or prediction interval limit(s) should be calculated.
A linear model object of type ‘lm’.
A numeric value between 0 and 1 specifying the significance
level for the calculation of confidence or prediction intervals. The
default is 0.05.
A character string of either "confidence" or
"prediction", i.e. specifying the type of interval of interest.
The default is "confidence".
A character string specifying if a “one sided” or
a “two sided” interval should be calculated, i.e. either
"one.sided" or "two.sided", respectively. The default is
"one.sided".
A character string specifying if the “upper” or the
“lower” limit is the relevant limit, i.e. either "upper" or
"lower", respectively. The default is "lower".
The function get_intvl_limit() calculates the upper or lower
confidence or prediction interval limit(s) for the linear regression model
provided by model.