The function print_val() generates a character string for the purpose
to print a value on a plot (together with associated information).
print_val(val_name, val_value, val_unit, val_sf, prefix = "", suffix = "")A single character string of the form “val_name: val_value (with the number of specified decimal places) val_unit”.
A character string specifying the text preceding the value of the parameter to be displayed.
A numeric value specifying the value of the parameter to be displayed.
A character string specifying the text following the value of the parameter to be displayed.
A positive integer specifying the number of significant figures for the display of the limit.
A character string at the beginning of the whole text. The
default is an empty string, i.e. "".
A character string at the end of the whole text. The default
is an empty string, i.e. "".
The function print_val() generates a character string that
is based on the provided information. The string is used as label of a
corresponding graph element. For the number formatting, the
sprintf() function from the ‘base’ package
is used. For concatenation of the various elements, the
paste() function from the ‘base’ package
is used.